==> qcad-3.15.5.3.tgz: lib/qcad/scripts/Projection/IsometricProjection/IsoProject/ts/IsoProject_es.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="es_ES">
<context>
    <name>IsoProject</name>
    <message>
        <source>Back</source>
        <translation type="obsolete">Atrás</translation>
    </message>
    <message>
        <source>Reference point</source>
        <translation type="obsolete">Punto de referencia</translation>
    </message>
    <message>
        <source>Target point</source>
        <translatorcomment>--google--
Especifique punto de destino
Capa de puntos objetivo
Usar sólo los puntos objetiva más cercanos (k):</translatorcomment>
        <translation type="obsolete">Punto objetivo</translation>
    </message>
    <message>
        <location filename="../IsoProjectInit.js" line="+2"/>
        <source>&amp;Isometric Projection</source>
        <translatorcomment>--exact match--
--file: qcadactions_es.ts--
Proyección &amp;Isométrica</translatorcomment>
        <translation>Proyección &amp;isométrica</translation>
    </message>
    <message>
        <source>Isometric Projection</source>
        <translation type="obsolete">Proyección &amp;Isométrica</translation>
    </message>
    <message>
        <location filename="../IsoProject.ui" line="+17"/>
        <source>Top</source>
        <translation>Parte superior</translation>
    </message>
    <message>
        <source>ProjectionType</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">ProjectionType</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Bottom</source>
        <translation>Parte inferior</translation>
    </message>
    <message>
        <location line="+41"/>
        <source>Left back</source>
        <translation>Izquierda trasera</translation>
    </message>
    <message>
        <location line="+24"/>
        <source>Right</source>
        <translation>Derecha</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Right back</source>
        <translation>Derecha trasera</translation>
    </message>
    <message>
        <location line="+24"/>
        <source>Rotate selection counter-clockwise before projection</source>
        <translation>Rotar contador dirección reloj antes de la proyección</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>Rotate selection clockwise before projection</source>
        <translation>Girar hacia la derecha antes de la proyección</translation>
    </message>
    <message>
        <source>Rotate counter-clockwise</source>
        <translation type="obsolete">Rotar contador dirección reloj</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation type="obsolete">Rotar dirección reloj</translation>
    </message>
    <message>
        <location line="+18"/>
        <source>Scale projection to original size (&apos;isometric drawing&apos;)</source>
        <translation>Proyección escala con el tamaño original</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>True scale</source>
        <translation>Escala real</translation>
    </message>
    <message>
        <location line="-114"/>
        <source>Left</source>
        <translation>Izquierda</translation>
    </message>
    <message>
        <source>Front</source>
        <translation type="obsolete">Frente</translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/Projection/IsometricProjection/IsoProject/ts/IsoProject_es.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="es_ES">
<context>
    <name>IsoProject</name>
    <message>
        <source>Back</source>
        <translation type="obsolete">Atrás</translation>
    </message>
    <message>
        <source>Reference point</source>
        <translation type="obsolete">Punto de referencia</translation>
    </message>
    <message>
        <source>Target point</source>
        <translatorcomment>--google--
Especifique punto de destino
Capa de puntos objetivo
Usar sólo los puntos objetiva más cercanos (k):</translatorcomment>
        <translation type="obsolete">Punto objetivo</translation>
    </message>
    <message>
        <location filename="../IsoProjectInit.js" line="+2"/>
        <source>&amp;Isometric Projection</source>
        <translatorcomment>--exact match--
--file: qcadactions_es.ts--
Proyección &amp;Isométrica</translatorcomment>
        <translation>Proyección &amp;isométrica</translation>
    </message>
    <message>
        <source>Isometric Projection</source>
        <translation type="obsolete">Proyección &amp;Isométrica</translation>
    </message>
    <message>
        <location filename="../IsoProject.ui" line="+17"/>
        <source>Top</source>
        <translation>Parte superior</translation>
    </message>
    <message>
        <source>ProjectionType</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">ProjectionType</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Bottom</source>
        <translation>Parte inferior</translation>
    </message>
    <message>
        <location line="+41"/>
        <source>Left back</source>
        <translation>Izquierda trasera</translation>
    </message>
    <message>
        <location line="+24"/>
        <source>Right</source>
        <translation>Derecha</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Right back</source>
        <translation>Derecha trasera</translation>
    </message>
    <message>
        <location line="+24"/>
        <source>Rotate selection counter-clockwise before projection</source>
        <translation>Rotar contador dirección reloj antes de la proyección</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>Rotate selection clockwise before projection</source>
        <translation>Girar hacia la derecha antes de la proyección</translation>
    </message>
    <message>
        <source>Rotate counter-clockwise</source>
        <translation type="obsolete">Rotar contador dirección reloj</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation type="obsolete">Rotar dirección reloj</translation>
    </message>
    <message>
        <source>Scale projection to original size (&apos;isometric drawing&apos;)</source>
        <translation type="vanished">Proyección escala con el tamaño original</translation>
    </message>
    <message>
        <source>True scale</source>
        <translation type="vanished">Escala real</translation>
    </message>
    <message>
        <location line="-93"/>
        <source>Left</source>
        <translation>Izquierda</translation>
    </message>
    <message>
        <source>Front</source>
        <translation type="obsolete">Frente</translation>
    </message>
    <message>
        <location filename="../IsoProject.js" line="+50"/>
        <source>Isometric</source>
        <translation>Isométrica</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Isometric True Scale</source>
        <translation>Isométrica escala real</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Planometric</source>
        <translation>Planimétrica</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Dimetric</source>
        <translation>Dimétrico</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <source>Cabinet</source>
        <translation>Caballera</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Cavalier</source>
        <translation>Caballera especial</translation>
    </message>
</context>
</TS>
